duodata.vo.examenkandidaten
=======================

DUO publiceert op [haar site](https://duo.nl/open_onderwijsdata/databestanden/vo/) gegevens
over het voortgezet onderwijs. Het formaat van de gepubliceerde gegevens is wat onhandig
om mee te werken, daarom worden ze omgezet
in [tidy-format](http://vita.had.co.nz/papers/tidy-data.html)

.. testsetup::

    from duodata.vo.examenkandidaten import 

.. automodule:: duodata.vo.examenkandidaten
    :members:
